==> dde-shell_2.0.1.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль индикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Современный Режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Эффективный Режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Классический режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Режим центрирования</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Отображать Всегда</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Держать Скрытым</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Умное Скрытие</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Настройки Dock</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Заблокировать док</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль индикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Современный Режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Эффективный Режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Классический режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Режим центрирования</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Сверху</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Снизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Отобразить</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Умное скрытие</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Настройки дока</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Заблокировать док</translation>
    </message>
</context>
</TS>
